==> react-daily-components-0.5.4.tgz: package/lib/esm/utilities/css.js <==
export var getColorByStatus = function (props) {
    return props.active ? getPrimaryColor(props) : getDefaultColor(props);
};
export var getPrimaryColor = function (props) {
    var _a, _b;
    if ("primaryColor" in props)
        return (_a = props.primaryColor) !== null && _a !== void 0 ? _a : "gray";
    return (_b = props.theme.primaryColor) !== null && _b !== void 0 ? _b : "gray";
};
export var getDefaultColor = function (props) {
    var _a, _b;
    if ("defaultColor" in props)
        return (_a = props.defaultColor) !== null && _a !== void 0 ? _a : "gray";
    return (_b = props.theme.defaultColor) !== null && _b !== void 0 ? _b : "gray";
};
/**
 * Generate Ripple Effect at Button Click
 * @param event
 * @param theme
 * @param primary
 */
export var rippleEffect = function (event, theme, primary) {
    var button = event.currentTarget;
    // create container for circle
    var container = document.createElement("div");
    container.style.width = "".concat(button.offsetWidth, "px");
    container.style.height = "".concat(button.offsetHeight, "px");
    container.style.borderRadius = "inherit";
    container.classList.add("container");
    // create circle
    var circle = document.createElement("span");
    var diameter = Math.max(button.clientWidth, button.clientHeight);
    var radius = diameter / 2;
    circle.style.width = circle.style.height = "".concat(diameter, "px");
    circle.style.top = "".concat(event.nativeEvent.offsetY - radius, "px");
    circle.style.left = "".concat(event.nativeEvent.offsetX - radius, "px");
    circle.style.backgroundColor = primary ? getPrimaryColor(theme) : "#fff";
    circle.style.opacity = primary ? "0.3" : "1";
    circle.classList.add("ripple");
    // remove container, if already exist ripple
    var ripple = button.getElementsByClassName("container")[0];
    if (ripple) {
        ripple.remove();
    }
    // append ripple to button inside
    container.appendChild(circle);
    button.appendChild(container);
};

==> react-daily-components-0.5.6.tgz: package/lib/esm/utilities/css.js <==
export var getColorByStatus = function (active, theme) {
    return active ? getPrimaryColor(theme) : getDefaultColor(theme);
};
export var getPrimaryColor = function (theme) {
    var _a;
    return (_a = theme === null || theme === void 0 ? void 0 : theme.primaryColor) !== null && _a !== void 0 ? _a : "gray";
};
export var getDefaultColor = function (theme) {
    var _a;
    return (_a = theme === null || theme === void 0 ? void 0 : theme.defaultColor) !== null && _a !== void 0 ? _a : "gray";
};
/**
 * Generate Ripple Effect at Button Click
 * @param event
 * @param theme
 * @param primary
 */
export var rippleEffect = function (event, theme, primary) {
    var button = event.currentTarget;
    // create container for circle
    var container = document.createElement("div");
    container.style.width = "".concat(button.offsetWidth, "px");
    container.style.height = "".concat(button.offsetHeight, "px");
    container.style.borderRadius = "inherit";
    container.classList.add("container");
    console.log(event.nativeEvent.offsetY);
    console.log(event.nativeEvent.offsetX);
    console.log(event);
    // create circle
    var circle = document.createElement("span");
    var diameter = Math.max(button.clientWidth, button.clientHeight);
    var radius = diameter / 2;
    circle.style.width = circle.style.height = "".concat(diameter, "px");
    circle.style.top = "".concat(event.nativeEvent.offsetY - radius, "px");
    circle.style.left = "".concat(event.nativeEvent.offsetX - radius, "px");
    circle.style.backgroundColor = primary
        ? getPrimaryColor(theme)
        : "rgba(255, 255, 255, 0.5)";
    circle.style.opacity = primary ? "0.3" : "1";
    circle.classList.add("ripple");
    // remove container, if already exist ripple
    var ripple = button.getElementsByClassName("container")[0];
    if (ripple) {
        ripple.remove();
    }
    // append ripple to button inside
    container.appendChild(circle);
    button.appendChild(container);
};
